//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//Clippoly.cpp
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//
//A  few  functions  to perform
//Sutherland-Hodgman  X,Y poly-
//gon  clipping  with  accurate
//results. 
//
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//Author: John De Goes
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//
//NOTE: Parameters invertex and outvertex can NOT be the same variable, as
//outvertex is modified dynamically.  The variables inlength and outlength 
//must also be different variables.  When the function returns,  outlength
//will hold the new number of vertices the clipped polygon has.
//
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//Before using this file(s), see Readme.txt.
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//
//Example code:
//
//Clip_Right(vert1,vert2,length1,length2);
//Clip_Left(vert2,vert1,length2,length1);
//Clip_Top(vert1,vert2,length1,length2);
//Clip_Bottom(vert2,vert1,length2,length1);
//
//if (length1) 
//   Draw_Polygon(vert1,length1);
//
//
//Where Draw_Polygon is your own polygon drawing function.
//
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


//Set for 320x200 (any size will work though)
const long YMIN=0;
const long YMAX=199;
const long XMIN=0;
const long XMAX=319;

struct Screen_Vertex {
long X, Y; 				// The screen x and y positions of the point
float Z;   				// 1/Z at vertex
};

void Clip_Left(const Screen_Vertex *invertex, Screen_Vertex *outvertex, int inlength, int &outlength);
void Clip_Top(const Screen_Vertex *invertex, Screen_Vertex *outvertex, int inlength, int &outlength);
void Clip_Right(const Screen_Vertex *invertex, Screen_Vertex *outvertex, int inlength, int &outlength);
void Clip_Bottom(const Screen_Vertex *invertex, Screen_Vertex *outvertex, int inlength, int &outlength);

